import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
import { ComplexComputedList } from "cdktf";
/**
 *
 */
export interface IngressConfig extends TerraformMetaArguments {
    /**
     * Terraform will wait for the load balancer to have at least 1 endpoint before considering the resource created.
     */
    readonly waitForLoadBalancer?: boolean;
    /**
     * metadata block.
     */
    readonly metadata: IngressMetadata[];
    /**
     * spec block.
     */
    readonly spec: IngressSpec[];
}
/**
 *
 */
export declare class IngressLoadBalancerIngress extends ComplexComputedList {
    /**
     *
     */
    get hostname(): string;
    /**
     *
     */
    get ip(): string;
}
/**
 *
 */
export interface IngressMetadata {
    /**
     * An unstructured key value map stored with the ingress that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Prefix, used by the server, to generate a unique name ONLY IF the `name` field has not been provided.
     *
     * This value will also be combined with a unique suffix. Read more: https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api-conventions.md#idempotency
     */
    readonly generateName?: string;
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the ingress.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the ingress, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the ingress must be unique.
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface IngressSpecBackend {
    /**
     * Specifies the name of the referenced service.
     */
    readonly serviceName?: string;
    /**
     * Specifies the port of the referenced service.
     */
    readonly servicePort?: string;
}
/**
 *
 */
export interface IngressSpecRuleHttpPathBackend {
    /**
     * Specifies the name of the referenced service.
     */
    readonly serviceName?: string;
    /**
     * Specifies the port of the referenced service.
     */
    readonly servicePort?: string;
}
/**
 *
 */
export interface IngressSpecRuleHttpPath {
    /**
     * Path is matched against the path of an incoming request.
     *
     * Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/'. When unspecified, all paths from incoming requests are matched.
     */
    readonly path?: string;
    /**
     * backend block.
     */
    readonly backend?: IngressSpecRuleHttpPathBackend[];
}
/**
 *
 */
export interface IngressSpecRuleHttp {
    /**
     * path block.
     */
    readonly path: IngressSpecRuleHttpPath[];
}
/**
 *
 */
export interface IngressSpecRule {
    /**
     * Host is the fully qualified domain name of a network host, as defined by RFC 3986.
     *
     * Note the following deviations from the "host" part of the URI as defined in RFC 3986: 1. IPs are not allowed. Currently an IngressRuleValue can only apply to
     * the IP in the Spec of the parent Ingress.
     * 2. The `:` delimiter is not respected because ports are not allowed.
     * Currently the port of an Ingress is implicitly :80 for http and
     * :443 for https.
     * Both these may change in the future. Incoming requests are matched against the host before the IngressRuleValue. If the host is unspecified, the Ingress routes all traffic based on the specified IngressRuleValue.
     *
     * Host can be "precise" which is a domain name without the terminating dot of a network host (e.g. "foo.bar.com") or "wildcard", which is a domain name prefixed with a single wildcard label (e.g. "*.foo.com"). The wildcard character '*' must appear by itself as the first DNS label and matches only a single label. You cannot have a wildcard label by itself (e.g. Host == "*"). Requests will be matched against the Host field in the following way: 1. If Host is precise, the request matches this rule if the http host header is equal to Host. 2. If Host is a wildcard, then the request matches this rule if the http host header is to equal to the suffix (removing the first label) of the wildcard rule.
     */
    readonly host?: string;
    /**
     * http block.
     */
    readonly http: IngressSpecRuleHttp[];
}
/**
 *
 */
export interface IngressSpecTls {
    /**
     * Hosts are a list of hosts included in the TLS certificate.
     *
     * The values in this list must match the name/s used in the tlsSecret. Defaults to the wildcard host setting for the loadbalancer controller fulfilling this Ingress, if left unspecified.
     */
    readonly hosts?: string[];
    /**
     * SecretName is the name of the secret used to terminate TLS traffic on port 443.
     *
     * Field is left optional to allow TLS routing based on SNI hostname alone. If the SNI host in a listener conflicts with the "Host" header field used by an IngressRule, the SNI host is used for termination and value of the Host header is used for routing.
     */
    readonly secretName?: string;
}
/**
 *
 */
export interface IngressSpec {
    /**
     * backend block.
     */
    readonly backend?: IngressSpecBackend[];
    /**
     * rule block.
     */
    readonly rule?: IngressSpecRule[];
    /**
     * tls block.
     */
    readonly tls?: IngressSpecTls[];
}
/**
 *
 */
export declare class Ingress extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: IngressConfig);
    private _id?;
    /**
     *
     */
    get id(): string | undefined;
    /**
     *
     */
    set id(value: string | undefined);
    /**
     *
     */
    loadBalancerIngress(index: string): IngressLoadBalancerIngress;
    private _waitForLoadBalancer?;
    /**
     *
     */
    get waitForLoadBalancer(): boolean | undefined;
    /**
     *
     */
    set waitForLoadBalancer(value: boolean | undefined);
    private _metadata;
    /**
     *
     */
    get metadata(): IngressMetadata[];
    /**
     *
     */
    set metadata(value: IngressMetadata[]);
    private _spec;
    /**
     *
     */
    get spec(): IngressSpec[];
    /**
     *
     */
    set spec(value: IngressSpec[]);
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
